Skip to contents

Make a named bed into a list of GRanges objects to be used with pairwise functions, mostly.

Usage

import_named_bed_into_list(bedpath)

Arguments

bedpath

A path to a bedfile

Value

A list of GRanges objects