Make a named bed into a list of GRanges objects to be used with pairwise functions, mostly.
import_named_bed_into_list.RdMake a named bed into a list of GRanges objects to be used with pairwise functions, mostly.
import_named_bed_into_list.RdMake a named bed into a list of GRanges objects to be used with pairwise functions, mostly.